Learn R Programming

happytime (version 0.1.0)

runfood: What to Eat Today

Description

A small program is used to decide what to eat today, and currently only contains delicious Guangdong dishes.

Usage

runfood()

Arguments

Examples

Run this code
# NOT RUN {
runfood()

# }

Run the code above in your browser using DataLab