powered by
A small program is used to decide what to eat today, and currently only contains delicious Guangdong dishes.
runfood()
# NOT RUN { runfood() # }
Run the code above in your browser using DataLab